@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 2.6.0   2019/03/05
+ * Version: 2.6.0+   2020/01/01
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -745,8 +745,6 @@ static void make_path_group(void)
 	echo("path_group ANY_PATHNAME \\*:/\\{\\*\\}/");
 	echo("path_group ANY_PATHNAME \\*:/\\{\\*\\}/\\*");
 	echo("path_group ANY_PATHNAME \\*:[\\$]");
-	echo("path_group ANY_PATHNAME "
-	     "socket:[family=\\$:type=\\$:protocol=\\$]");
 	echo("path_group ANY_DIRECTORY /");
 	echo("path_group ANY_DIRECTORY /\\{\\*\\}/");
 	echo("path_group ANY_DIRECTORY \\*:/");
