@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2014/01/05
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -235,9 +235,9 @@ int main(int argc, char *argv[])
 	printf("Usage: %s [remote_ip:remote_port]\n\n", argv[0]);
 	printf("This program is used for granting access requests manually."
 	       "\n");
-	printf("This program shows access requests that are about to rejected "
-	       "by the kernel's decision.\n");
-	printf("If you answer before the kernel's decision taken effect, your "
+	printf("This program shows access requests that are about to be "
+	       "rejected by the kernel's decision.\n");
+	printf("If you answer before the kernel's decision takes effect, your "
 	       "decision will take effect.\n");
 	printf("You can use this program to respond to accidental access "
 	       "requests triggered by non-routine tasks (such as restarting "
